bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.plates_multiplier
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: WrapToGaussianGammaARD.plates_multiplier